@@ -5,12 +5,12 @@ use warnings;
 
 package MongoDBI::Document::Base;
 {
-  $MongoDBI::Document::Base::VERSION = '0.0.12';
+    $MongoDBI::Document::Base::VERSION = '0.02';
 }
 
 use 5.001000;
 
-our $VERSION = '0.0.12'; # VERSION
+our $VERSION = '0.02';    # VERSION
 
 use Moose ('with');
 use Moose::Exporter;
@@ -18,10 +18,7 @@ use MooseX::Traits;
 use MongoDBI::Document::Sugar ();
 
 my ($import, $unimport, $init_meta) = Moose::Exporter->build_import_methods(
-    also             => [
-        'Moose',
-        'MongoDBI::Document::Sugar',
-    ],
+    also             => ['Moose', 'MongoDBI::Document::Sugar',],
     base_class_roles => [
         'MongoDBI::Document::Storage',
         'MongoDBI::Document::Storage::Operation',
@@ -30,7 +27,7 @@ my ($import, $unimport, $init_meta) = Moose::Exporter->build_import_methods(
 
 sub init_meta {
     my ($dummy, %opts) = @_;
-    
+
     my $meta = Moose->init_meta(%opts);
     Moose::Util::MetaRole::apply_base_class_roles(
         for   => $opts{for_class},
@@ -40,64 +37,53 @@ sub init_meta {
             'MongoDBI::Document::Storage::Operation',
         ]
     );
-    
+
     # all document class instances should have an _dirty attribute
     # for tracking dirty columns as they are changed
     $meta->add_attribute(
         '_dirty' => (
-            is => 'rw',
-            isa => 'HashRef',
-            default => sub {{
-                
-            }}
+            is      => 'rw',
+            isa     => 'HashRef',
+            default => sub { {} },
         )
     );
-    
+
     # all document class instances should have an _id field
     # as they represent documents in a collection
     $meta->add_attribute(
         '_id' => (
-            is => 'rw',
+            is  => 'rw',
             isa => 'MongoDB::OID'
         )
     );
-    
+
     # all document class instances should has a convenience
     # accessor for the special _id attr
     $meta->add_method(
         'id' => sub {
-            my $self = shift ;
+            my $self = shift;
             return $self->_id ? $self->_id->value : 0;
         }
     );
-    
+
     # all document class instances should be able to access
     # the special configuration attribute
     $meta->add_method(
         'config' => sub {
-            shift->_config
+            shift->_config;
         }
     );
-    
+
     # determine whether and/or which fields have been changed
     $meta->add_method(
         'changed' => sub {
             my ($self, $field) = @_;
-            return $field ?
-                scalar (defined $self->_dirty->{$field}) :
-                scalar (values %{ $self->_dirty }) ;
+            return $field
+              ? scalar($self->_dirty->{$field})
+              : scalar(values %{$self->_dirty});
         }
     );
-    
-    # determine whether if/how fields have been changed
-    $meta->add_method(
-        'change' => sub {
-            my ($self, $field) = @_;
-            return $self->changed($field) ?
-                $self->_dirty->{$field}->[-1] : 0 ;
-        }
-    );
-    
+
     return Class::MOP::class_of($opts{for_class});
 }
 
@@ -111,4 +97,4 @@ sub unimport {
     goto &$unimport;
 }
 
-1;
\ No newline at end of file
+1;
